"""
Component Subsystem
===================

Component subsystem for extending the application.
@since: 0.96
"""

import msgs
from exc import *
from Component import Component
#from Viewer import Viewer
from View import View
from Player import Player
from Thumbnailer import Thumbnailer
from Widget import Widget
from Configurator import Configurator
#from MediaWidgetFactory import MediaWidgetFactory
from Container import Container
